package Acme::MadokaMagica::TvMembers::TomoeMami;
use parent qw/Acme::MadokaMagica::TvMembers/;
use utf8;


1;

__DATA__

@@ TomoeMami
firstname: マミ
lastname: 巴
age: 15
birthday: 8/28
blood_type: O
cv: 水橋かおり
say: ティロ・フィナーレ!!
witchename: Candeloro
color: yellow
